ObjectWriteRequest

Struct ObjectWriteRequest 

pub struct ObjectWriteRequest<'a> {
    pub code: &'a [u8],
    pub sections: &'a [Section],
    pub symbols: &'a [ObjectSymbol],
    pub relocations: &'a [ExternalReloc],
    pub target_arch: TargetArchitecture,
    pub target_os: TargetOperatingSystem,
    pub opts: &'a ObjectWriteOptions,
}
All data needed to write a single relocatable object file.

Passed to ObjectWriter::write_object_file so the trait method signature stays below clippy’s argument-count threshold without losing any information.

Fields

code: &'a [u8]sections: &'a [Section]symbols: &'a [ObjectSymbol]relocations: &'a [ExternalReloc]target_arch: TargetArchitecturetarget_os: TargetOperatingSystemopts: &'a ObjectWriteOptions