Object file generation: ELF (Linux/BSD), Mach-O (macOS), COFF/PE (Windows).
Structs
- Coff
Writer - ElfWriter
- External
Reloc - A relocation entry for an unresolved (external) symbol reference.
offsetis the byte offset within the code section of the 4-byte displacement field. - MachO
Writer - Object
Symbol - A symbol with its resolved offset within its defining section, ready for the object file symbol table. Built by the assembler after two-pass resolution.
- Object
Write Options - Extra sections and metadata for
ObjectWriterbackends. - Object
Write Request - All data needed to write a single relocatable object file.
Traits
- Object
Writer - Backend for writing relocatable object files (ELF, Mach-O, or COFF/PE).
Functions
- object_
writer_ for_ os - Returns the object writer for
target_os(ELF, Mach-O, or COFF).